%define with_maven 1
%define with_repolib 1
%define repodir %{_javadir}/repository.jboss.com/org/jvnet/staxex/%{version}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

Name:          stax-ex
Version:       1.4
Release:       %mkrel 1
Summary:       StAX API extensions
Group:         Development/Java
License:       CDDL, GPL
Url:           https://stax-ex.dev.java.net/
# svn export https://svn.java.net/svn/stax-ex~svn/tags/stax-ex-1.4 stax-ex-1.4
# tar czf stax-ex-1.4-src-svn.tar.gz stax-ex-1.4
Source0:       stax-ex-1.4-src-svn.tar.gz
Source1:       stax-ex-1.4-autogeneratedfiles.tar.gz
Source2:       stax-ex-component-info.xml
Patch0:        stax-ex-1.4-pom_xml.patch
BuildRequires: ant
BuildRequires: ant-junit
BuildRequires: glassfish-jaf
BuildRequires: glassfish-stax-api
%if %with_maven
BuildRequires: maven
BuildRequires: maven-ant-plugin
BuildRequires: maven-changes-plugin
BuildRequires: maven-compiler-plugin
BuildRequires: maven-doxia-sitetools
BuildRequires: maven-install-plugin
BuildRequires: maven-jar-plugin
BuildRequires: maven-javadoc-plugin
BuildRequires: maven-plugin-plugin
BuildRequires: maven-resources-plugin
BuildRequires: maven-surefire-plugin
BuildRequires: package-rename-task
%else
BuildRequires: hamcrest
%endif
BuildRequires: java-devel
BuildRequires: junit
BuildRequires: jpackage-utils
Requires:      glassfish-jaf
Requires:      glassfish-stax-api
Requires:      jpackage-utils
BuildArch:     noarch

%description
This project develops a few extensions to complement JSR-173 StAX API in the
following area.

1. Enable parser instance reuse (which is important in the
	high-performance environment like JAXB and JAX-WS)
2. Improve the support for reading from non-text XML infoset,
	such as FastInfoset.
3. Improve the namespace support.

%package javadoc
Group:         Development/Java
Summary:       Javadoc for %{name}
Requires:      %{name} = %{version}-%{release} 
Requires:      jpackage-utils

%description javadoc
STAX extensions.

This package contains javadoc for %{name}.

%if %with_repolib
%package repolib
Group:          Development/Java
Summary:        Artifacts to be uploaded to a repository library

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%setup -q -n stax-ex-%{version}
%patch0 -p0

iconv -f iso8859-1 -t utf-8 LICENSE.txt > LICENSE.txt.conv && mv -f LICENSE.txt.conv LICENSE.txt
sed -i 's/\r//' LICENSE.txt

for j in $(find . -name "*.jar"); do
  rm -f $j
done

%if !%with_maven
  tar -xf %{SOURCE1}
# TODO change conveniently the maven-build.xml file
%endif

%build

export MAVEN_REPO_LOCAL=$PWD/.m2/repository
%if %with_maven
  mkdir -p $MAVEN_REPO_LOCAL

  mvn-jpp \
    -Dmaven.compile.target=1.5 \
    -Dmaven.javadoc.source=1.5  \
    -e \
    -Dmaven.test.skip=true \
    -Dmaven.repo.local=$MAVEN_REPO_LOCAL \
    ant:ant install javadoc:javadoc
#

%else
# TODO
%endif

%install
[ %{buildroot} != / ] && rm -rf %{buildroot}

mkdir -p %{buildroot}%{_javadir}
install -m 644 target/stax-ex-%{version}.jar \
  %{buildroot}%{_javadir}/stax-ex-%{version}.jar

(
  cd %{buildroot}%{_javadir}
  for jar in *-%{version}*; do
    ln -sf ${jar} ${jar/-%{version}/}
  done
)

mkdir -p %{buildroot}%{_mavenpomdir}
install -pm 644 pom.xml %{buildroot}%{_mavenpomdir}/JPP-stax-ex.pom
%add_maven_depmap JPP-stax-ex.pom stax-ex.jar

mkdir -p %{buildroot}%{_javadocdir}/stax-ex-%{version}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/stax-ex-%{version}
ln -s stax-ex-%{version} %{buildroot}%{_javadocdir}/stax-ex

%if %with_repolib
mkdir -p %{buildroot}%{repodir}
mkdir -p %{buildroot}%{repodirlib}
install -pm 644 %{SOURCE2} %{buildroot}%{repodir}/component-info.xml
tag=`/bin/echo stax-ex-%{version}-%{release} | %{__sed} 's|\.|_|g'`
%{__sed} -i "s/@TAG@/$tag/g" %{buildroot}%{repodir}/component-info.xml
%{__sed} -i "s/@VERSION@/%{version}-brew/g" %{buildroot}%{repodir}/component-info.xml
mkdir -p %{buildroot}%{repodirsrc}
install -pm 644 %{SOURCE0} %{buildroot}%{repodirsrc}
install -pm 644 %{SOURCE1} %{buildroot}%{repodirsrc}
install -pm 644 %{PATCH0} %{buildroot}%{repodirsrc}
cp -p %{buildroot}%{_javadir}/stax-ex-%{version}.jar %{buildroot}%{repodirlib}/stax-ex.jar
%endif

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%{_javadir}/stax-ex-%{version}.jar
%{_javadir}/stax-ex.jar
%{_mavenpomdir}/*
%{_mavendepmapfragdir}/*
%doc LICENSE.txt

%files javadoc
%{_javadocdir}/stax-ex-%{version}
%{_javadocdir}/stax-ex

%if %with_repolib
%files repolib
%{repodir}
%endif



%changelog
* Thu Aug 11 2011 dmorgan <dmorgan> 1.4-1.mga2
+ Revision: 132725
- Fix typo
- Clean spec file

  + gil <gil>
    - update to 1.4
    - imported package stax-ex


* Sun Jul 03 2011 gil <gil> 1.2-0.%%mkrel
- initial rpm